=======
CHANGES
=======

0.9.8
-----

- Make the Deps recipe compatible with the Compile recipe by adding in the
  `filename` option.

0.9.7
-----

- Update recipe to generate all contents on import so that we can generate
  configuration details.

0.9.6
-----

-

0.9.5
-----

- Update to latest closure compiler.

0.9.4
-----

- Package the contents correctly.

0.9.3
-----
- Update closurebuilder and the closure compiler.

0.9.2
-----

- Add filename to the Compile recipe options directory. So it can be referenced.

0.9.1
-----

- Add missing files into the distribution.

0.9
---

- Initial release.
